from django import forms
import core_app.models
from . import models

# class SignupForm(forms.Form):
    # name         = forms.CharField()
    # email        = forms.EmailField()
    # password     = forms.CharField()
    # organization = forms.CharField()







