#! /usr/bin/env python3

from distutils.core import setup

setup(name="django-paybills",
      version="1.0.0",
      description="Django app for paypal integration.",
      packages=["paybills"],
      author="Iury O. G. Figueiredo",
      author_email="ioliveira@id.uff.br",
      url='',
      download_url='',
      keywords=[],
      classifiers=[])































































